import SafeEventEmitter from "@metamask/safe-event-emitter";
import { WalletLinkAnalyticsAbstract } from "../init";
import { ScopedLocalStorage } from "../lib/ScopedLocalStorage";
import { WalletLinkRelayAbstract } from "../relay/WalletLinkRelayAbstract";
import { WalletLinkRelayEventManager } from "../relay/WalletLinkRelayEventManager";
import { AddressString, Callback } from "../types";
import { JSONRPCRequest, JSONRPCResponse } from "./JSONRPC";
import { RequestArguments, Web3Provider } from "./Web3Provider";
export interface WalletLinkProviderOptions {
    chainId?: number;
    jsonRpcUrl: string;
    overrideIsCoinbaseWallet?: boolean;
    overrideIsMetaMask: boolean;
    relayEventManager: WalletLinkRelayEventManager;
    relayProvider: () => Promise<WalletLinkRelayAbstract>;
    storage: ScopedLocalStorage;
    walletLinkAnalytics?: WalletLinkAnalyticsAbstract;
}
export declare class WalletLinkProvider extends SafeEventEmitter implements Web3Provider {
    readonly isCoinbaseWallet: boolean;
    private readonly _filterPolyfill;
    private readonly _subscriptionManager;
    private readonly _relayProvider;
    private _relay;
    private readonly _storage;
    private readonly _relayEventManager;
    private readonly _walletLinkAnalytics;
    private _jsonRpcUrlFromOpts;
    private readonly _overrideIsMetaMask;
    private _addresses;
    private hasMadeFirstChainChangedEmission;
    constructor(options: Readonly<WalletLinkProviderOptions>);
    get selectedAddress(): AddressString | undefined;
    get networkVersion(): string;
    get chainId(): string;
    get isWalletLink(): boolean;
    /**
     * Some DApps (i.e. Alpha Homora) seem to require the window.ethereum object return
     * true for this method.
     */
    get isMetaMask(): boolean;
    get host(): string;
    get connected(): boolean;
    isConnected(): boolean;
    private get jsonRpcUrl();
    private set jsonRpcUrl(value);
    private get isChainOverridden();
    private set isChainOverridden(value);
    setProviderInfo(jsonRpcUrl: string, chainId: number): void;
    private updateProviderInfo;
    private addEthereumChain;
    private switchEthereumChain;
    setAppInfo(appName: string, appLogoUrl: string | null): void;
    enable(): Promise<AddressString[]>;
    close(): void;
    send(request: JSONRPCRequest): JSONRPCResponse;
    send(request: JSONRPCRequest[]): JSONRPCResponse[];
    send(request: JSONRPCRequest, callback: Callback<JSONRPCResponse>): void;
    send(request: JSONRPCRequest[], callback: Callback<JSONRPCResponse[]>): void;
    send<T = any>(method: string, params?: any[] | any): Promise<T>;
    sendAsync(request: JSONRPCRequest, callback: Callback<JSONRPCResponse>): void;
    sendAsync(request: JSONRPCRequest[], callback: Callback<JSONRPCResponse[]>): void;
    request<T>(args: RequestArguments): Promise<T>;
    scanQRCode(match?: RegExp): Promise<string>;
    genericRequest(data: object, action: string): Promise<string>;
    supportsSubscriptions(): boolean;
    subscribe(): void;
    unsubscribe(): void;
    disconnect(): boolean;
    private _send;
    private _sendAsync;
    private _sendRequest;
    private _setAddresses;
    private _sendRequestAsync;
    private _sendMultipleRequestsAsync;
    private _handleSynchronousMethods;
    private _handleAsynchronousMethods;
    private _handleAsynchronousFilterMethods;
    private _handleSubscriptionMethods;
    private _isKnownAddress;
    private _ensureKnownAddress;
    private _prepareTransactionParams;
    private _requireAuthorization;
    private _throwUnsupportedMethodError;
    private _signEthereumMessage;
    private _ethereumAddressFromSignedMessage;
    private _eth_accounts;
    private _eth_coinbase;
    private _net_version;
    private _eth_chainId;
    private getChainId;
    private _eth_requestAccounts;
    private _eth_sign;
    private _eth_ecRecover;
    private _personal_sign;
    private _personal_ecRecover;
    private _eth_signTransaction;
    private _eth_sendRawTransaction;
    private _eth_sendTransaction;
    private _eth_signTypedData_v1;
    private _eth_signTypedData_v3;
    private _eth_signTypedData_v4;
    private _walletlink_arbitrary;
    private _wallet_addEthereumChain;
    private _wallet_switchEthereumChain;
    private _eth_uninstallFilter;
    private _eth_newFilter;
    private _eth_newBlockFilter;
    private _eth_newPendingTransactionFilter;
    private _eth_getFilterChanges;
    private _eth_getFilterLogs;
    private initializeRelay;
}
